# -*- coding: utf-8 -*-

""" Coworking cowoker testing module """

from datetime import date
from odoo import fields
from odoo.exceptions import ValidationError
from odoo.tests.common import TransactionCase

class TestCoworkingCoworker(TransactionCase):
    """ Coworking cowoker testing """

    def setUp(self, *args, **kwargs):
        """ Bootstrap testing """
        super(TestCoworkingCoworker, self).setUp(*args, **kwargs)
        data = {'name': 'Homer Simpson', 'is_coworker': True}
        self.homer = self.env['res.partner'].create(data)

    def test_contact_date(self):
        """ Test contact date : default to today and validity """
        contact_date = fields.Date.from_string(self.homer.contact_date)
        self.assertEqual(contact_date, date.today())

        marge = self.env['res.partner'].create({'name': 'Marge Simpson',
                                                'contact_date': '2017-01-01'})
        self.assertEqual(marge.contact_date, '2017-01-01')

        with self.assertRaises(ValidationError) as err:
            data = {'name': 'Bart Simpson', 'contact_date': '2999-01-01'}
            self.env['res.partner'].create(data)
        self.assertIn('equal of inferior to', unicode(err.exception))

    def test_full_address(self):
        """Test full address"""
        self.homer.write({'street': False, 'zip': False, 'city': False})
        self.assertEqual(self.homer.full_contact_adress, u'')

        self.homer.write({'street': False, 'zip': False, 'city': u'Springfield'})
        self.assertEqual(self.homer.full_contact_adress, u'Springfield')

        self.homer.write({'street': False, 'zip': u'5555', 'city': u'Springfield'})
        self.assertEqual(self.homer.full_contact_adress, u'5555 Springfield')

        self.homer.write({'street': u'42 Liberty Street', 'zip': u'5555', 'city': u'Springfield'})
        self.assertEqual(self.homer.full_contact_adress, u'42 Liberty Street 5555 Springfield')

        self.homer.write({'street': u'42 Liberty Street', 'zip': False, 'city': u'Springfield'})
        self.assertEqual(self.homer.full_contact_adress, u'42 Liberty Street  Springfield')


    def test_manage_coworker_type(self):
        """ Test that non-coworker have not coworker_type fixed """
        self.homer.write({'is_coworker': False})
        self.assertFalse(self.homer.coworker_type)

        self.homer.write({'coworker_type': 'visitor'})
        self.assertEqual(self.homer.coworker_type, 'visitor')

        self.homer.write({'is_coworker': False, 'coworker_type': 'staffer'})
        self.assertFalse(self.homer.coworker_type)
